"""
hudai.resources
"""

from .article_highlights import ArticleHighlightsResource
from .article_key_term import ArticleKeyTermResource
from .article_tag import ArticleTagResource
from .article import ArticleResource
from .company_key_term import CompanyKeyTermResource
from .company import CompanyResource
from .domain import DomainResource
from .key_term import KeyTermResource
from .person import PersonResource
from .person_key_term import PersonKeyTermResource
from .person_quote import PersonQuoteResource
from .relevant_articles import RelevantArticlesResource
from .system_event import SystemEventResource
from .system_task import SystemTaskResource
from .text_corpus import TextCorpusResource
from .user_company import UserCompanyResource
from .user_digest_subscription import UserDigestSubscriptionResource
from .user_key_term import UserKeyTermResource
from .user import UserResource
